@@ -4,7 +4,6 @@
 import logging
 from typing import NamedTuple
 
-
 class Table:
     attributes = {}
     repr_attributes = ["id"]
@@ -224,6 +223,18 @@ class Frames:
                 where_clause.append(
                     f"ST_DWithin(geom::geography, {st_point}::geography, {distance})")
                 continue
+            if arg == "distance":
+                point, operator, distance = value
+                st_point = f"ST_SetSRID(ST_Point({point[0]}, {point[1]}), 4326)"
+                where_clause.append(
+                    f"ST_Distance(geom::geography, {st_point}::geography) {operator}")
+                params.append(distance)
+                continue
+            if arg == "time_interval":
+                start, end = value
+                orderby_clause.append("stamp")
+                where_clause.append(f"stamp BETWEEN '{start}' AND '{end}'")
+                continue
             if arg in select_clause:
                 if type(value) != tuple:
                     value = (value,)
