@@ -11,11 +11,23 @@ import logging
 from horus_media import Client, Geometry
 
 
+class read_arguments_from_file(argparse.Action):
+    def __call__(self, parser, namespace, values, option_string=None):
+        file_name = None
+        if option_string == "--db-file":
+            file_name = namespace.db_file
+
+        if option_string == "--s-file":
+            file_name = namespace.s_file
+
+        if file_name != None:
+            f = open(file_name, "r")
+            parser.parse_args(f.read().split(), namespace)
+
 def create_argument_parser():
     return argparse.ArgumentParser(
         formatter_class=argparse.ArgumentDefaultsHelpFormatter)
 
-
 def add_database_arguments(parser):
     # db
     parser.add_argument("--db-name", type=str,
@@ -29,6 +41,8 @@ def add_database_arguments(parser):
     parser.add_argument("--db-port", type=int, default=5432,
                         help="database connection port number")
 
+    parser.add_argument('--db-file', help="database configuration file", type=str,default="input/db.conf",action=read_arguments_from_file,nargs=0)
+
 
 def add_server_arguments(parser):
     parser.add_argument("-s", "--server",  metavar="URL", type=str, default="http://localhost:5050/web/",
@@ -38,6 +52,8 @@ def add_server_arguments(parser):
     parser.add_argument("-sa", "--server-attempts",  metavar="ATTEMPTS", type=int, default=5,
                         help="Horus Media Server number of attempts on connection failure")
 
+    parser.add_argument('--s-file', help="server configuration file",type=str, default="input/server.conf", action=read_arguments_from_file, nargs=0)
+
 
 def add_size_argument(parser, default=(1024, 1024)):
     parser.add_argument("-S", "--size",  metavar=("WIDTH", "HEIGHT"), nargs=2, type=int, default=default,
@@ -89,4 +105,10 @@ def get_client(args):
         return client
     except OSError as exception:
         logging.error(f"{exception}. Connecting to server {args.server}")
-        exit()
+        exit(1)
+
+
+def sample_script_header(name):
+    if name == "__main__":
+        print(f"This module is a sample script. It cannot run as an interactive example.")
+        exit(1)
